/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.xsl.content.web.internal.display.context;

import com.liferay.portal.kernel.module.configuration.ConfigurationException;
import com.liferay.portal.kernel.theme.PortletDisplay;
import com.liferay.portal.kernel.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.WebKeys;
import com.liferay.xsl.content.web.configuration.XSLContentConfiguration;
import com.liferay.xsl.content.web.configuration.XSLContentPortletInstanceConfiguration;
import com.liferay.xsl.content.web.internal.util.XSLContentUtil;

import java.net.URL;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;

/**
 * @author Juergen Kappler
 */
public class XSLContentDisplayContext {

	public XSLContentDisplayContext(
			HttpServletRequest request,
			XSLContentConfiguration xslContentConfiguration)
		throws ConfigurationException {

		_xslContentConfiguration = xslContentConfiguration;

		_themeDisplay = (ThemeDisplay)request.getAttribute(
			WebKeys.THEME_DISPLAY);

		PortletDisplay portletDisplay = _themeDisplay.getPortletDisplay();

		_xslContentPortletInstanceConfiguration =
			portletDisplay.getPortletInstanceConfiguration(
				XSLContentPortletInstanceConfiguration.class);
	}

	public String getContent(ServletRequest servletRequest) throws Exception {
		if (_content != null) {
			return _content;
		}

		HttpServletRequest request = (HttpServletRequest)servletRequest;

		String contextPath = request.getContextPath();

		String xmlUrl = XSLContentUtil.replaceUrlTokens(
			_themeDisplay, contextPath,
			_xslContentPortletInstanceConfiguration.xmlUrl());

		String xslUrl = XSLContentUtil.replaceUrlTokens(
			_themeDisplay, contextPath,
			_xslContentPortletInstanceConfiguration.xslUrl());

		_content = XSLContentUtil.transform(
			_xslContentConfiguration, new URL(xmlUrl), new URL(xslUrl));

		return _content;
	}

	public XSLContentPortletInstanceConfiguration
		getXSLContentPortletInstanceConfiguration() {

		return _xslContentPortletInstanceConfiguration;
	}

	private String _content;
	private final ThemeDisplay _themeDisplay;
	private final XSLContentConfiguration _xslContentConfiguration;
	private final XSLContentPortletInstanceConfiguration
		_xslContentPortletInstanceConfiguration;

}